#
# spec file for package python-zope.interface
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%global modname zope.interface
%{?sle15_python_module_pythons}
Name:           python-zope.interface%{psuffix}
Version:        7.2
Release:        2.1
Summary:        Interfaces for Python
License:        ZPL-2.1
URL:            https://pypi.python.org/pypi/zope.interface
Source:         https://files.pythonhosted.org/packages/source/z/%{modname}/%{modname}-%{version}.tar.gz
# needed for tests that try to compile things
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module zope.event}
BuildRequires:  %{python_module zope.interface = %{version}}
BuildRequires:  %{python_module zope.testing}
%endif
# /SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
%python_subpackages

%description
This package is intended to be independently reusable in any Python
project. It is maintained by the Zope Toolkit project.

This package provides an implementation of object interfaces for Python.
Interfaces are a mechanism for labeling objects as conforming to a given
API or contract. So, this package can be considered as implementation of
the Design By Contract methodology support in Python.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand rm %{buildroot}%{$python_sitearch}/zope/interface/_zope_interface_coptimizations.c
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%check
%if %{with test}
cd src
%pyunittest zope/interface/{common/,}tests/test_*.py
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt COPYRIGHT.txt
%doc CHANGES.rst README.rst
%{python_sitearch}/zope[_.]interface-%{version}.dist-info
%{python_sitearch}/zope.interface-%{version}*-nspkg.pth
%dir %{python_sitearch}/zope
%{python_sitearch}/zope/interface

%endif

%changelog
* Tue Apr  1 2025 Markéta Machová <mmachova@suse.com>
- Make it compatible with older setuptools
* Mon Mar 24 2025 Steve Kowalik <steven.kowalik@suse.com>
- Correct dist-info directory due to new setuptools.
* Mon Jan 20 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 7.2
  * Add preliminary support for Python 3.14a2, this means that
    ``.common.builtins.IByteString`` and ``.common.collections.IByteString`` are
    no longer available from this Python version onwards as Python 3.14 dropped
    ``collections.abc.ByteString``.
* Wed Oct 30 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 7.1.1
  * Fix segmentation faults in `weakrefobject.c`
    on Python 3.12 and 3.13. (#323)
- Adjust upstream source name in spec file
* Mon Oct 14 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 7.1.0:
  * Declare support for Python 3.13.
  * Fix segmentation faults on Python 3.13. (#323)
- Drop patch fix-testsuite-segfault.patch, included upstream.
- Switch to autosetup macros.
* Wed Sep 25 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick upstream patch to fix testsuite segfault with Python 3.13
  * fix-testsuite-segfault.patch
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 7.0.3:
  * Fix Assertion 'memb->type == T_PYSSIZET' failed. for Python <
    3.12.
  * Fix reference-counting bug in C module initialization (broken
    in 7.0).
  * Fix subclassability of ObjectSpecificationDescriptor (broken
    in 7.0).
  * Enable heap-based types (PEP 384) for Python >= 3.11.
  * Adopt multi-phase module initialization (PEP 489).
  * Drop support for Python 3.7.
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 6.4.post2:
  * Publish missing Windows wheels, second attempt.
  * Publish missing Windows wheels.
  * The sdist of version 6.4 was uploaded to PyPI as
    zope_interface-6.4.tar.gz instead of
    zope.interface-6.4-py2.tar.gz which cannot be installed by
    zc.buildout.  This release is a re-release of version 6.4
    with the correct sdist name.
  * Adjust for incompatible changes in Python 3.13b1.
  * Build windows wheels on GHA.
* Wed May  8 2024 Dirk Müller <dmueller@suse.com>
- update to 6.3:
  * Add preliminary support for Python 3.13 as of 3.13a6.
* Wed Mar 13 2024 Dirk Müller <dmueller@suse.com>
- update to 6.2:
  * Add preliminary support for Python 3.13 as of 3.13a3.
  * Add support to use the pipe (|) syntax for typing.Union.
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- remove python2 specific codepaths
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 6.1:
  * Add support for Python 3.12.
  * Fix building of the docs for non-final versions.
* Fri May  5 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0:
  * Build Linux binary wheels for Python 3.11.
  * Drop support for Python 2.7, 3.5, 3.6.
  * Fix test deprecation warning on Python 3.11.
  * Add preliminary support for Python 3.12 as of 3.12a5.
  * Drop:
  * + `zope.interface.implements`
  * + `zope.interface.implementsOnly`
  * + `zope.interface.classProvides`
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Dec  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.5.2
  * Add support for building arm64 wheels on macOS.
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.5.1
  * Add support for final Python 3.11 release.
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.5.0
  * Add support for Python 3.10 and 3.11 (as of 3.11.0rc2).
  * Add missing Trove classifier showing support for Python 3.9.
  * Add some more entries to zope.interface.interfaces.__all__.
  * Disable unsafe math optimizations in C code. See pull request 262.
* Wed Oct 13 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
- added sources
  + _multibuild
* Fri Jul  9 2021 Jason Craig <os@jacraig.com>
- Update to 5.4.0
  * many changes, see CHANGES.rst
* Mon Feb  8 2021 Matej Cepl <mcepl@suse.com>
- Don't switch off python36 build, half of python-* packages depend on it.
* Wed Feb  3 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 5.2.0
  * Add documentation section ``Persistency and Equality``
  * Create arm64 wheels.
  * Add support for Python 3.9.
- Fix build on tumbleweed
* Tue Apr 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.1.0:
  * Make @implementer(*iface) and classImplements(cls, *iface) ignore redundant interfaces. If the class already implements an interface through inheritance, it is no longer redeclared specifically for cls. This solves many instances of inconsistent resolution orders, while still allowing the interface to be declared for readability and maintenance purposes. See issue 199.
  * Remove all bare except: statements. Previously, when accessing special attributes such as __provides__, __providedBy__, __class__ and __conform__, this package wrapped such access in a bare except: statement, meaning that many errors could pass silently; typically this would result in a fallback path being taken and sometimes (like with providedBy()) the result would be non-sensical. This is especially true when those attributes are implemented with descriptors. Now, only AttributeError is caught. This makes errors more obvious.
  * In addition, ZODB errors like POSKeyError could now be propagated where previously they would ignored by this package.
  * Require that the second argument (bases) to InterfaceClass is a tuple. This only matters when directly using InterfaceClass to create new interfaces dynamically. Previously, an individual interface was allowed, but did not work correctly. Now it is consistent with type and requires a tuple.
  * Let interfaces define custom __adapt__ methods. This implements the other side of the PEP 246 adaptation protocol: objects being adapted could already implement __conform__ if they know about the interface, and now interfaces can implement __adapt__ if they know about particular objects. There is no performance penalty for interfaces that do not supply custom __adapt__ methods.
  * Make the internal singleton object returned by APIs like implementedBy and directlyProvidedBy for objects that implement or provide no interfaces more immutable. Previously an internal cache could be mutated. See issue 204.
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 5.0.1
  * lot of changes, see CHANGES.rst
* Mon Mar 16 2020 pgajdos@suse.com
- version update to 4.7.2
  - Remove deprecated use of setuptools features.  See `issue 30
    <https://github.com/zopefoundation/zope.interface/issues/30>`_.
* Mon Dec  9 2019 Steve Kowalik <steven.kowalik@suse.com>
- update to 4.7.1:
  * Use Python 3 syntax in the documentation. See issue 119.
  * Drop support for Python 3.4.
  * Fix queryTaggedValue, getTaggedValue, getTaggedValueTags subclass
    inheritance. See PR 144.
  * Add support for Python 3.8.
* Fri Apr  5 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.6.0
  * Add support for Python 3.7
  * Fix verifyObject for class objects with staticmethods on Python 3.
* Thu Dec  6 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Tue Aug 28 2018 tchvatal@suse.com
- Version update to 4.5.0:
  * Allow registering and unregistering instance methods as listeners. See issue 12 and PR 102.
  * Synchronize and simplify zope/__init__.py. See issue 114
  * Avoid exceptions when the __annotations__ attribute is added to interface definitions with Python 3.x type hints. See issue 98.
  * Fix the possibility of a rare crash in the C extension when deallocating items. See issue 100.
* Mon Jun 19 2017 okurz@suse.com
- Cover building python3 packages as well
* Sat Jun 17 2017 okurz@suse.com
- Update to 4.4.2
  * Fix a regression storing zope.component.persistentregistry.PersistentRegistry instances. See issue 85.
  * Fix a regression that could lead to the utility registration cache of Components getting out of sync. See issue 93.
- Update to 4.4.1
  * Simplify the caching of utility-registration data. In addition to simplification, avoids spurious test failures when checking for leaks in tests with persistent registries. See pull 84.
  * Raise ValueError when non-text names are passed to adapter registry methods: prevents corruption of lookup caches.
- Update to 4.4.0
  * Avoid a warning from the C compiler. (https://github.com/zopefoundation/zope.interface/issues/71)
  * Add support for Python 3.6.
- Update to 4.3.3
  * Correct typos and ReST formatting errors in documentation.
  * Add API documentation for the adapter registry.
  * Ensure that the LICENSE.txt file is included in built wheels.
  * Fix C optimizations broken on Py3k. See the Python bug at: http://bugs.python.org/issue15657 (https://github.com/zopefoundation/zope.interface/issues/60)
- Update to 4.3.2
  * Fix equality testing of implementedBy objects and proxies. (https://github.com/zopefoundation/zope.interface/issues/55)
- Prevent duplicate doc package generation
- Cleanup duplicates in build tree
* Sat Mar 11 2017 okurz@suse.com
- Convert package to singlespec
* Tue Nov 15 2016 dmueller@suse.com
- update to 4.3.1:
- Support Components subclasses that are not hashable.
  (https://github.com/zopefoundation/zope.interface/issues/53)
- Add the ability to sort the objects returned by ``implementedBy``.
  This is compatible with the way interface classes sort so they can
  be used together in ordered containers like BTrees.
  (https://github.com/zopefoundation/zope.interface/issues/42)
- Make ``setuptools`` a hard dependency of ``setup.py``.
- Change a linear algorithm (O(n)) in ``Components.registerUtility`` and
  ``Components.unregisterUtility`` into a dictionary lookup (O(1)) for
  hashable components. This substantially improves the time taken to
  manipulate utilities in large registries at the cost of some
  additional memory usage. (https://github.com/zopefoundation/zope.interface/issues/46)
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.1.2:
  * Add support for PyPy3.
  * Remove unittest assertions deprecated in Python3.x.
  * Add zope.interface.document.asReStructuredText, which formats
    the generated text for an interface using ReST double-backtick
    markers.
- fix documentation generation
- pass -q to test to avoid spamming the build log
* Tue Sep 16 2014 tbechtold@suse.com
- Update to version 4.1.1:
  * Added support for Python 3.4.
* Sun Feb 16 2014 os-dev@jacraig.com
- Update to 4.1.0:
  * Updated ``boostrap.py`` to version 2.2.
  * Added ``@named(name)`` declaration, that specifies the component name, so
    it does not have to be passed in during registration.
- Change source URL, .zip not available for this version.
* Thu Dec 19 2013 coolo@suse.com
- BuildIgnore our own name - required by python-repoze.sphinx.autointerface,
  but of course not needed
* Thu Aug  1 2013 hpj@urpla.net
- add unzip to BuildRequires
* Thu Aug  1 2013 speilicke@suse.com
- Ship upstream tarbal (zipfile) and fix Source URL
* Mon Jul 29 2013 hpj@urpla.net
- Updated to 4.0.5:
  * Fixed a bug where a decorated method caused false positive failures on verifyClass().
- Updated to 4.0.4:
  * Fixed a bug that was revealed by porting zope.traversing. During a loop, the loop body modified a weakref dict causing a RuntimeError error.
- generate documentation in -doc package
- enable tests
* Mon Jan 14 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to 4.0.3 version:
  * Fleshed out PyPI Trove classifiers.
- Remove duplicate files with fdupes
* Sun Oct 14 2012 douglarek@outlook.com
- Fix spec bugs
- Updated to 4.0.1
  * Dropped explicit DeprecationWarnings for "class advice" APIS (these APIs are still deprecated under Python 2.x, and still raise an exception under Python 3.x, but no longer cause a warning to be emitted under Python 2.x).
  * Automated build of Sphinx HTML docs and running doctest snippets via tox.
  * Deprecated the "class advice" APIs from zope.interface.declarations: implements, implementsOnly, and classProvides. In their place, prefer the equivalent class decorators: @implementer, @implementer_only, and @provider. Code which uses the deprecated APIs will not work as expected under Py3k.
  * Removed use of '2to3' and associated fixers when installing under Py3k. The code is now in a "compatible subset" which supports Python 2.6, 2.7, and 3.2, including PyPy 1.8 (the version compatible with the 2.7 language spec).
  * Dropped explicit support for Python 2.4 / 2.5 / 3.1.
  * Added support for PyPy.
  * Added support for continuous integration using tox and jenkins.
  * Added 'setup.py dev' alias (runs setup.py develop plus installs nose and coverage).
  * Added 'setup.py docs' alias (installs Sphinx and dependencies).
  * Replaced all unittest coverage previously accomplished via doctests with unittests. The doctests have been moved into a docs section, managed as a Sphinx collection.
  * LP #910987: Ensure that the semantics of the lookup method of zope.interface.adapter.LookupBase are the same in both the C and Python implementations.
  * LP #900906: Avoid exceptions due to tne new __qualname__ attribute added in Python 3.3 (see PEP 3155 for rationale). Thanks to Antoine Pitrou for the patch.
* Wed Feb  1 2012 saschpe@suse.de
- Simplified macro usage
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 3.8.0:
  * New module zope.interface.registry
  * No longer Python 2.4 compatible (tested under 2.5, 2.6, 2.7, and 3.2).
* Tue Sep  6 2011 saschpe@suse.de
- Added provides/obsoletes for python-zope-interface
* Tue Sep  6 2011 saschpe@suse.de
- Renamed to python-zope.interface (from python-zopeinterface)
- Simplyfied spec file
- Update to version 3.7.0:
  * LP #570942: Now correctly compare interfaces from different modules
    but with the same names.
  * LP #811792:  work around buggy behavior in some subclasses of
    zope.interface.interface.InterfaceClass, which invoke __hash__
    before initializing __module__ and __name__.  The workaround
    returns a fixed constant hash in such cases, and issues a UserWarning.
  * LP #804832: Under PyPy, zope.interface should not build its C
    extension. Also, prevent attempting to build it under Jython.
  * Add a tox.ini for easier xplatform testing.
  * Fix testing deprecation warnings issued when tested under Py3K.
  * LP 804951: InterfaceClass instances were unhashable under Python 3.x.
  * LP #570942: Now correctly compare interfaces  from different modules
    but with the same names.
* Wed Dec 15 2010 saschpe@suse.de
- add documentation files: COPYRIGHT.txt CHANGES.txt LICENSE.txt
* Sun Dec 12 2010 saschpe@gmx.de
- update to 3.6.1
  * A non-ascii character in the changelog made 3.6.0 uninstallable
    on Python 3 systems with another default encoding than UTF-8.
  * Fixed compiler warnings under GCC 4.3.3.
  * Python 2.3 is no longer supported.
  * Use the standard Python doctest module instead of
    zope.testing.doctest, which has been deprecated.
  * Allow to bootstrap on Jython.
- re-packaged with py2pack
  * now builds on all RPM-based distros
* Tue Jun  3 2008 crrodriguez@suse.de
- needs fno-strict-aliasing
* Thu Aug  2 2007 jmatejek@suse.cz
- update to 3.3.0
  * corresponds to new Zope versions
  * adapter-lookup written in C to simplify application debugging
  * various bugfixes
* Thu Oct 19 2006 jmatejek@suse.cz
- minor changes for better 64bit compatibility with PEP353
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Apr 14 2005 mcihar@suse.cz
- new package
